# Comp-Lead [![PyPI](https://img.shields.io/pypi/v/comp-lead?color=blue)](https://pypi.org/project/comp-lead/)

This is my first PyPI package, so this is very simple. This package displays a handful of tech leaders and companies (five to be exact).
The reason why I decided to create this package was to just understand the way packages are built and how they are published.

### Usage:

Installation:

```sh
pip install comp-lead
```

Import:

```python
from comp_lead import sample
```

Run: 

```python
sample.obj.displayLead()

sample.com.displayComp()
```